twitch

package
v0.0.0-...-aeaa42d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2020 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// Client holds the client for Twitch API access
	Client *helix.Client
)

Functions

func CreateSession

func CreateSession(clientID string, clientSecret string) error

CreateSession creates a new session to the Twitch API

func GetStreams

func GetStreams(channels []string) (*[]helix.Stream, error)

GetStreams returns a list of channels from twitch

func UpdateAppToken

func UpdateAppToken() error

UpdateAppToken updates client authorization with a new app token when needed

Types

This section is empty.

Jump to