Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Client holds the client for Twitch API access Client *helix.Client )
Functions ¶
func CreateSession ¶
CreateSession creates a new session to the Twitch API
func GetStreams ¶
GetStreams returns a list of channels from twitch
func UpdateAppToken ¶
func UpdateAppToken() error
UpdateAppToken updates client authorization with a new app token when needed
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.